use warnings;
use strict;
use Carp;

use Test::More;
use Test::Exception;

use Data::Dumper;

use POWER::GPG;
$POWER::GPG::DEBUG = $ENV{DEBUG_GPG} ? 2 : 0;

use vars qw( $HOMEDIR @KEY_ID @LONGKEY_ID %KEY_INFO %PUB_KEY %SEC_KEY );


$HOMEDIR = 't/.gnupg';
# predefined keys from t/keys/
@KEY_ID  = qw(
    FE16DF1D47DC6D256831D15B1034FDDD9E7CF4FD
    E68138DE40F86B9E749DBBB1CFEE26EE327DF9BA
    B249E4BC0A5431EA3605AB2AF58A5EBD217221B9
    4824A8FC966A9893480D8A5E523B72417042063D
);
@LONGKEY_ID = qw(
    1034FDDD9E7CF4FD
    CFEE26EE327DF9BA
);
%KEY_INFO= (
    'FE16DF1D47DC6D256831D15B1034FDDD9E7CF4FD'    => [
        {
            name    => 'POWER Email 2',
            comment => 'test',
            email   => 'root@localhost',
        },
    ],
    'E68138DE40F86B9E749DBBB1CFEE26EE327DF9BA'    => [
        {
            name    => 'Baba Yaga',
            comment => 'pensioner',
            email   => 'yaga@deepforest.ru',
        },
    ],
    'B249E4BC0A5431EA3605AB2AF58A5EBD217221B9'    => [
        {
            name    => 'Zmey Gorynich',
            comment => q{},
            email   => q{},
        },
    ],
    '4824A8FC966A9893480D8A5E523B72417042063D'    => [
        {
            'name'      => 'First Last',
            'comment'   => '',
            'email'     => 'real@e.mail',
        },
        {
            'name'      => q{(":\)},
            'comment'   => q{<"':>},
            'email'     => q{cool@e.mail},
        },
        {
            'name'      => 'First',
            'comment'   => 'Alias',
            'email'     => 'e@ma.il',
        },
        {
            'name'      => 'First (Alias)',
            'comment'   => 'comment',
            'email'     => '',
        },
    ],
);
for (@KEY_ID) {
    $PUB_KEY{$_} = `cat t/keys/\Q$_\E.pub`;
    $SEC_KEY{$_} = `cat t/keys/\Q$_\E.sec`;
}


sub init_gpg_homedir {
    system("chmod 0700 \Q$HOMEDIR\E &>/dev/null; rm -rf \Q$HOMEDIR\E");
    mkdir $HOMEDIR;
    chmod 0700, $HOMEDIR;
    return;
}

sub delete_secret_and_public {
    POWER::GPG::_gpg_run(['--delete-secret-and-public-key', shift]);
    return;
}

gpg_config({ homedir => $HOMEDIR });


1;
