use warnings;
use strict;
use Carp;

BEGIN { require 't/.lib.t' }
plan tests => 24;

my ($encrsign, $plain, $sig);

init_gpg_homedir();

throws_ok { gpg_encrypt_sign()                      } qr/Usage/;
throws_ok { gpg_encrypt_sign(q{})                   } qr/Usage/;
throws_ok { gpg_encrypt_sign(0, 0, 0, 0)            } qr/Usage/;
throws_ok { gpg_encrypt_sign(undef, [])             } qr/undefined/;
throws_ok { gpg_encrypt_sign(q{}, [])               } qr/list is empty/;
throws_ok { gpg_encrypt_sign(q{}, [$KEY_ID[0]])     } qr/no default secret key/;

gpg_import($SEC_KEY{ $KEY_ID[1] }, 1);
throws_ok { gpg_encrypt_sign(q{}, [$KEY_ID[0]])     } qr/public key not found|No public key/;
lives_ok  { gpg_encrypt_sign(q{}, [$KEY_ID[1]])     } 'empty msg for key2';

gpg_import($PUB_KEY{ $KEY_ID[0] });
lives_ok  { gpg_encrypt_sign(q{}, [$KEY_ID[0]])     } 'empty msg for key1';
lives_ok  { gpg_encrypt_sign('test', [$KEY_ID[0]])  } 'test  msg for key1';
lives_ok  { gpg_encrypt_sign('test', [@KEY_ID[0,1]], [$KEY_ID[1]])
                                                    } 'test  msg for key1+2';

throws_ok { gpg_encrypt_sign(q{}, [$KEY_ID[0]], [$KEY_ID[0]])
                                                    } qr/secret key not available|No secret key/;
throws_ok { gpg_encrypt_sign(q{}, [$KEY_ID[0]], [@KEY_ID[0,1]])
                                                    } qr/secret key not available|No secret key/;

gpg_import($SEC_KEY{ $KEY_ID[0] }, 1);
lives_ok  { $encrsign = gpg_encrypt_sign('test', [@KEY_ID[0,1]], [@KEY_ID[0,1]])
                                                    } 'encr&sign for key1+2';

lives_ok  { ($plain, $sig) = gpg_decrypt($encrsign) } '  decrypted';
is($plain, 'test',                                    '  ... text correct');
is_deeply($sig, { $KEY_ID[0] => 1, $KEY_ID[1] => 1 }, '  ... sig correct');

delete_secret_and_public($KEY_ID[1]);
lives_ok  { ($plain, $sig) = gpg_decrypt($encrsign) } '  decrypted';
is($plain, 'test',                                    '  ... text correct');
is_deeply($sig, { $KEY_ID[0]=>1, $LONGKEY_ID[1]=>0 }, '  ... sig correct');

delete_secret_and_public($KEY_ID[0]);
throws_ok { ($plain, $sig) = gpg_decrypt($encrsign) } qr/secret key not available|No secret key/;

gpg_import($SEC_KEY{ $KEY_ID[1] }, 1);
lives_ok  { ($plain, $sig) = gpg_decrypt($encrsign) } '  decrypted';
is($plain, 'test',                                    '  ... text correct');
is_deeply($sig, { $KEY_ID[1]=>1, $LONGKEY_ID[0]=>0 }, '  ... sig correct');

