use warnings;
use strict;
use Carp;

BEGIN { require 't/.lib.t' }
plan tests => 14;

my @id;

init_gpg_homedir();

throws_ok { gpg_import()                    } qr/Usage/;
throws_ok { gpg_import(0, 0, 0)             } qr/Usage/;
throws_ok { gpg_import(undef)               } qr/undefined/;
throws_ok { gpg_import(q{})                 } qr/no valid OpenPGP data found/;
throws_ok { gpg_import('junk')              } qr/no valid OpenPGP data found/;
throws_ok { gpg_import(<<'EOKEY')           } qr/no valid OpenPGP data found|gpg killed by signal 6/;
-----BEGIN PGP PRIVATE KEY BLOCK-----
Version: GnuPG v1.4.2.2 (GNU/Linux)

lQG7BESdg2wRBADYZ4l3Rv8e8RQQ/hVDpifIPkhvcINmfbovBQAz1nv07mIKIDdI
-----END PGP PRIVATE KEY BLOCK-----
EOKEY

@id = gpg_import($PUB_KEY{ $KEY_ID[0] });
is_deeply(\@id, [ $KEY_ID[0] ], 'public key');

@id = gpg_import($PUB_KEY{ $KEY_ID[0] });
is_deeply(\@id, [ $KEY_ID[0] ], 'same public key, again');

@id = gpg_import($SEC_KEY{ $KEY_ID[0] }, 1);
is_deeply(\@id, [ $KEY_ID[0] ], 'secret key for already imported public key');

@id = gpg_import($SEC_KEY{ $KEY_ID[1] }, 1);
is_deeply(\@id, [ $KEY_ID[1] ], 'new secret key');

@id = gpg_import($SEC_KEY{ $KEY_ID[1] }, 1);
is_deeply(\@id, [ $KEY_ID[1] ], 'same secret key, again');

$SEC_KEY{ $KEY_ID[1].'-2' } = `cat t/keys/\Q$KEY_ID[1]\E.sec2`;
$PUB_KEY{ $KEY_ID[1].'-2' } = `cat t/keys/\Q$KEY_ID[1]\E.pub2`;

@id = gpg_import($SEC_KEY{ $KEY_ID[1].'-2' }.$PUB_KEY{ $KEY_ID[1].'-2' }, 1);
is_deeply(\@id, [ $KEY_ID[1] ], 'same secret+public key, again');

init_gpg_homedir();
@id = gpg_import(
      $PUB_KEY{ $KEY_ID[0] }
    . $PUB_KEY{ $KEY_ID[0] }
    . $SEC_KEY{ $KEY_ID[0] }
    . $SEC_KEY{ $KEY_ID[1] }
    , 1
);
is_deeply([sort @id], [sort @KEY_ID[0,1]], 'key1 public*2, key1 secret, key2 secret AT ONCE!');

init_gpg_homedir();
@id = gpg_import(
      $PUB_KEY{ $KEY_ID[0] }
    . $PUB_KEY{ $KEY_ID[0] }
    . "junk\n"
    . $SEC_KEY{ $KEY_ID[0] }
    . $SEC_KEY{ $KEY_ID[1] }
    , 1
);
is_deeply([sort @id], [sort @KEY_ID[0,1]], 'key1 public*2, JUNK, key1 secret, key2 secret AT ONCE!');

